@@ -4,7 +4,7 @@
 
 package Syntax::Highlight::Engine::Kate::Template;
 
-our $VERSION = '0.07';
+our $VERSION = '0.10';
 
 use strict;
 use Carp qw(cluck);
@@ -506,7 +506,7 @@ sub pluginGet {
 		if (defined($plug)) {
 			$plugs->{$language} = $plug;
 		} else {
-			$self->logwarning("cannot create plugin for language '$language'\n$@");
+			$self->logwarning("cannot create plugin for language '$language'\n--------------\n$@");
 		}
 	}
 	if (exists($plugs->{$language})) {
@@ -1182,4 +1182,4 @@ Perl itself
 
 =head1 SEE ALSO
 
-Synax::Highlight::Engine::Kate http:://www.kate-editor.org
\ No newline at end of file
+Synax::Highlight::Engine::Kate http:://www.kate-editor.org
